1. Test dataset — Spiker documentation

# 1. Test dataset

We used the H3K79me2 ChIP-seq data published by Orlando et al as the testing dataset. In this study, human Jurkat cells were treated with either DMSO or EPZ (Dot1L inhibitor), then collected individually and mixed according to the following compositions by cell number.

> 1. 100% DMSO to 0% EPZ

> 2. 75% DMSO to 25% EPZ.

> 3. 50% DMSO to 50% EPZ.

> 4. 25% DMSO to 75% EPZ.

> 5. 0% DMSO to 100% EPZ.

They tested whether traditional ChIP-seq analysis methods would reveal the decrease in human per-cell H3K79me2 occupancy and, if not, whether the addition of the exogenous Drosophila chromatin would allow detection of H3K79me2 removal. All data has been deposited into GEO with accession GSE60104.

# 2. H3K79me2 ChIP-seq data

Sample | SRR_accession | BAM (hg38 only) | bigWig files | BAM (hg38 + dm6)
Jurkat_K79_0%_R1 | SRR1536557 | bam | bigWig | bam
Jurkat_K79_25%_R1 | SRR1536558 | bam | bigWig | bam
Jurkat_K79_50%_R1 | SRR1536559 | bam | bigWig | bam
Jurkat_K79_75%_R1 | SRR1536560 | bam | bigWig | bam
Jurkat_K79_100%_R1 | SRR1536561 | bam | bigWig | bam

# 3. WCE (whole cell extract) data

Sample | SRR_accession | BAM (hg38 only)
Jurkat_WCE_0%_R1 | SRR1584489 | bam
Jurkat_WCE_25%_R1 | SRR1584490 | bam
Jurkat_WCE_50%_R1 | SRR1584491 | bam
Jurkat_WCE_75%_R1 | SRR1584492 | bam
Jurkat_WCE_100%_R1 | SRR1584493 | bam

# 4. MD5sum

    # K79 BAM files with reads only mapped to the human reference genome (GRCh38/hg38)
    MD5 (Jurkat_K79_00p_Rep1_SRR1536557_human.sorted.bam) = a4b8ac56f6ce4e1f9c0da2279ec3ea36
    MD5 (Jurkat_K79_25p_Rep1_SRR1536558_human.sorted.bam) = 56be607cb3ab886aa2fb033b4a8d37ab
    MD5 (Jurkat_K79_50p_Rep1_SRR1536559_human.sorted.bam) = 653170d551ce395e40b044cfa36fbaef
    MD5 (Jurkat_K79_75p_Rep1_SRR1536560_human.sorted.bam) = 23495e1422d9546ba496e69e2becd6f7
    MD5 (Jurkat_K79_100p_Rep1_SRR1536561_human.sorted.bam) = 2ebc83a02982a2be8deaca7b84651e44

    # K79 bigWig files generated by Spiker
    MD5 (K79_00p_R1.treat.hg38.SpikeIn_scaled.bigWig) = f13d2c6e228c87cf1d8262352f7e983c
    MD5 (K79_25p_R1.treat.hg38.SpikeIn_scaled.bigWig) = 0789024f52c35a3888254239dad6766a
    MD5 (K79_50p_R1.treat.hg38.SpikeIn_scaled.bigWig) = 83321afec8522f21c20baee3e772d85c
    MD5 (K79_75p_R1.treat.hg38.SpikeIn_scaled.bigWig) = bb64aafd851acb581742b581fa06cc5b
    MD5 (K79_100p_R1.treat.hg38.SpikeIn_scaled.bigWig) = aa2a38350a0dc07978b76297ea913dc3

    # K79 BAM files with reads mapped to the composite genome (hg38 + dm6)
    MD5 (Jurkat_K79_00p_Rep1_SRR1536557.sorted.bam) = 729b5391769c763eb1c85e5b2ee66af9
    MD5 (Jurkat_K79_25p_Rep1_SRR1536558.sorted.bam) = faffab3d3f9161304826c7f5bf84ee9e
    MD5 (Jurkat_K79_50p_Rep1_SRR1536559.sorted.bam) = 0c72e603c844fa8a38ca9fe8c2496a89
    MD5 (Jurkat_K79_75p_Rep1_SRR1536560.sorted.bam) = 9cac7b03ec65804ad3cb25143480348a
    MD5 (Jurkat_K79_100p_Rep1_SRR1536561.sorted.bam) = 05107197f676e8b898bee99ed001a61a

    # WCE BAM files with reads only mapped to the human reference genome (GRCh38/hg38)
    MD5 (Jurkat_WCE_00p_Rep1.SRR1584489_human.sorted.bam) = 561430e24b5edab177bfc4e832c5d8c0
    MD5 (Jurkat_WCE_100p_Rep1.SRR1584493_human.sorted.bam) = 8a8546927383afeda6c0e20f82807024
    MD5 (Jurkat_WCE_25p_Rep1.SRR1584490_human.sorted.bam) = 4396f3a31c718029d620dd770825df1e
    MD5 (Jurkat_WCE_50p_Rep1.SRR1584491_human.sorted.bam) = 96c5ae3cd9ad129167d2143fcb66606b
    MD5 (Jurkat_WCE_75p_Rep1.SRR1584492_human.sorted.bam) = 09b7ec2ecec4ccb7cce8392f88a17125